@@ -5,7 +5,8 @@
     { "whois.cira.ca",	"iso-8859-1",	NULL },
     { "whois.nic.ch",	"utf-8",	NULL },
     { "whois.nic.cl",	"iso-8859-1",	NULL },
-    { "whois.cnnic.net.cn",	"utf-8",	NULL },
+    { "whois.cnnic.cn",	"utf-8",	NULL },
+    { "cwhois.cnnic.cn",	"utf-8",	NULL },
     { "whois.nic.cz",	"utf-8",	NULL },
     { "whois.denic.de",	"utf-8",	NULL },
     { "whois.enum.denic.de",	"utf-8",	NULL },
